Ext.define('DSS.component.TimeSpanControl', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    numHour : null,
    numMinutes : null,
    numSeconds : null,
    timeField:null,
    padding : 5,
    lblHMS:null,
    lblFieldLabel:null,
    constructor : function(config) {
        this.numHour=Ext.create('Ext.form.field.Number', {
            allowBlank : false,
            allowDecimals : false,
            margin : '0 3 0 0',
            width : 50,
            value : 0,
            minValue : 0,
            maxValue : 23,
            minText: _("The minimum value for hour is 0"),
            maxText: _("The maximum value for hour is 23")

        });
        this.numMinutes=Ext.create('Ext.form.field.Number', {
            allowBlank : false,
            allowDecimals : false,
            margin : '0 3 0 0',
            width : 50,
            value : 0,
            minValue : 0,
            maxValue : 59,
            minText: _("The minimum value for minute is 0"),
            maxText: _("The maximum value for minute is 59")

        });
        this.numSeconds=Ext.create('Ext.form.field.Number', {
            allowBlank : false,
            allowDecimals : false,
            width : 50,
            value : 0,
            minValue : 0,
            maxValue : 59,        
            minText: _("The minimum value for second is 0"),
            maxText: _("The maximum value for second is 59")
        });
        this.lblFieldLabel  = Ext.create('Ext.form.Label',{
            html : config.fieldLabel,
            align : 'middle',
            margin : '3 10 0 5',
            width: 100
        }); 
        this.lblHMS  = Ext.create('Ext.form.Label',{
            text : '(' + _('hh:mm:ss') + ')',
            align : 'middle',
            margin : '3 0 0 5'
        }); 
        this.timeField = Ext.create('Ext.container.Container', {
            defaultType : 'numberfield',
            items : [this.lblFieldLabel , this.numHour, this.numMinutes, this.numSeconds,this.lblHMS ],
            layout : 'column',
            width : 600
        });


        Ext.apply(this, {
            items : [ this.timeField ]
        });
        this.callParent(arguments);
    },
    reset: function (){
        this.numHour.setValue(0);
        this.numMinutes.setValue(0);
        this.numSeconds.setValue(0);
    },
    setValue:function (value){
        var iSeconds=value%60;
        var iMinutes=Math.floor(value/60)%60;
        var iHour=Math.floor((value/60)/60);
        this.numHour.setValue(iHour);
        this.numMinutes.setValue(iMinutes);
        this.numSeconds.setValue(iSeconds);
    },
    isValid:function(){
        return this.numHour.isValid() && this.numMinutes.isValid() && this.numSeconds.isValid();
    },
    getValue : function(){
        var iReturnValue=0;
        iReturnValue=(this.numHour.getValue() * 60) * 60;
        iReturnValue+=this.numMinutes.getValue()*60;
        iReturnValue+=this.numSeconds.getValue();
        return iReturnValue;
    }
});